@@ -33,6 +33,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <X11/extensions/Xdamage.h>
 
+#include <xcb/xfixes.h>
+
 class NETWinInfo2;
 
 namespace KWin
@@ -188,7 +190,7 @@ public:
 
     // prefer isXXX() instead
     // 0 for supported types means default for managed/unmanaged types
-    NET::WindowType windowType(bool direct = false, int supported_types = 0) const;
+    virtual NET::WindowType windowType(bool direct = false, int supported_types = 0) const = 0;
     bool hasNETSupport() const;
     bool isDesktop() const;
     bool isDock() const;
@@ -284,6 +286,22 @@ public:
 
     virtual Layer layer() const = 0;
 
+    /**
+     * Resets the damage state and sends a request for the damage region.
+     * A call to this function must be followed by a call to getDamageRegionReply(),
+     * or the reply will be leaked.
+     *
+     * Returns true if the window was damaged, and false otherwise.
+     */
+    bool resetAndFetchDamage();
+
+    /**
+     * Gets the reply from a previous call to resetAndFetchDamage().
+     * Calling this function is a no-op if there is no pending reply.
+     * Call damage() to return the fetched region.
+     */
+    void getDamageRegionReply();
+
 signals:
     void opacityChanged(KWin::Toplevel* toplevel, qreal oldOpacity);
     void damaged(KWin::Toplevel* toplevel, const QRect& damage);
@@ -299,6 +317,11 @@ signals:
      * decoration.
      **/
     void shapedChanged();
+    /**
+     * Emitted whenever the state changes in a way, that the Compositor should
+     * schedule a repaint of the scene.
+     **/
+    void needsRepaint();
 
 protected:
     virtual ~Toplevel();
@@ -308,11 +331,14 @@ protected:
     virtual void damageNotifyEvent(XDamageNotifyEvent* e);
     Pixmap createWindowPixmap();
     void discardWindowPixmap();
-    void addDamage(const QRect& r);
-    void addDamage(int x, int y, int w, int h);
     void addDamageFull();
     void getWmClientLeader();
     void getWmClientMachine();
+    void setReadyForPainting();
+    /**
+     * @returns Whether there is a compositor and it is active.
+     **/
+    bool compositing() const;
 
     /**
      * This function fetches the opaque region from this Toplevel.
@@ -333,11 +359,12 @@ protected:
     int bit_depth;
     NETWinInfo2* info;
     bool ready_for_painting;
-    QTimer *m_readyForPaintingTimer;
     QRegion repaints_region; // updating, repaint just requires repaint of that area
     QRegion layer_repaints_region;
-protected slots:
-    void setReadyForPainting();
+
+protected:
+    bool m_isDamaged;
+
 private:
     static QByteArray staticWindowRole(WId);
     static QByteArray staticSessionId(WId);
@@ -351,7 +378,6 @@ private:
     Pixmap window_pix;
     Damage damage_handle;
     QRegion damage_region; // damage is really damaged window (XDamage) and texture needs
-    float damageRatio;
     bool is_shape;
     EffectWindowImpl* effect_window;
     QByteArray resource_name;
@@ -361,7 +387,9 @@ private:
     QByteArray window_role;
     bool unredirect;
     bool unredirectSuspend; // when unredirected, but pixmap is needed temporarily
+    bool m_damageReplyPending;
     QRegion opaque_region;
+    xcb_xfixes_fetch_region_cookie_t m_regionCookie;
     // when adding new data members, check also copyToDeleted()
 };
 
